package nl.iobyte.themeparkconnector.commands.arguments;

import nl.iobyte.commandapi.interfaces.ICommandArgument;
import nl.iobyte.commandapi.objects.ArgumentCheck;
import nl.iobyte.themeparkconnector.ThemeParkConnector;
import nl.iobyte.themeparkconnector.api.operator.objects.AttractionOperator;
import nl.iobyte.themeparkconnector.api.operator.objects.panel.OperatorItem;
import nl.iobyte.themeparkconnector.api.operator.objects.panel.OperatorItemState;
import org.bukkit.ChatColor;
import nl.iobyte.commandapi.interfaces.ICommandExecutor;
import java.util.Arrays;
import java.util.List;

public class OperatorArgument implements ICommandArgument<OperatorItemState> {

    /**
     * Message to display when giving an error
     * @return String
     */
    public String getMessage(String[] args) {
        return "Incorrect operator information: "+ ChatColor.WHITE +
                String.join(
                        ",",
                        Arrays.asList(args).subList(0, Math.min(args.length, 3))
                );
    }

    /**
     * Check if argument is valid OperatorItemState
     * @param sender ICommandExecutor
     * @param args Arguments passed by Command
     * @param previousArguments Previous arguments
     * @return Boolean
     */
    public ArgumentCheck checkArgument(ICommandExecutor sender, String[] args, List<Object> previousArguments) {
        if(args.length < 3)
            return new ArgumentCheck(false, 1);

        AttractionOperator operator = ThemeParkConnector.getInstance().getAPI().getOperatorService().getOperator(args[0]);
        if(operator == null)
            return new ArgumentCheck(false, 1);

        OperatorItem item = operator.getPanel().getItem(args[1]);
        if(item == null)
            return new ArgumentCheck(false, 1);

        return new ArgumentCheck(item.hasState(args[2]), 3);
    }

    /**
     * Get OperatorItemState passed by command
     * @param sender ICommandExecutor
     * @param args Arguments passed by Command
     * @param previousArguments Previous arguments
     * @return OperatorItemState
     */
    public OperatorItemState getArgument(ICommandExecutor sender, String[] args, List<Object> previousArguments) {
        AttractionOperator operator = ThemeParkConnector.getInstance().getAPI().getOperatorService().getOperator(args[0]);
        previousArguments.add(operator);

        OperatorItem item = operator.getPanel().getItem(args[1]);
        previousArguments.add(item);

        return item.getState(args[2]);
    }

}
